==> haskell-fmlist-0.9.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fmlist
version: 0.9.1
id: fmlist-0.9.1-D87L91OaHLhDSEB8cQftB0
key: fmlist-0.9.1-D87L91OaHLhDSEB8cQftB0
license: BSD3
maintainer: sjoerd@w3future.com
homepage: https://github.com/sjoerdvisscher/fmlist
synopsis: FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.
category: Data
author: Sjoerd Visscher
exposed: True
indefinite: False
exposed-modules:
    Data.FMList
abi: 44e92913d3c35971ebaabce505965d0c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fmlist-0.9.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/fmlist-0.9.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/fmlist-0.9.1
hs-libraries: HSfmlist-0.9.1-D87L91OaHLhDSEB8cQftB0
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html: /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fmlist-0.9.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fmlist
version: 0.9.2
id: fmlist-0.9.2-5s08raTrKC6Ifm5la47EVy
key: fmlist-0.9.2-5s08raTrKC6Ifm5la47EVy
license: BSD3
maintainer: sjoerd@w3future.com
homepage: https://github.com/sjoerdvisscher/fmlist
synopsis: FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.
category: Data
author: Sjoerd Visscher
exposed: True
indefinite: False
exposed-modules:
    Data.FMList
abi: 637d0e4e52c98cdaebe2ad87aabfd660
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fmlist-0.9.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/fmlist-0.9.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/fmlist-0.9.2
hs-libraries: HSfmlist-0.9.2-5s08raTrKC6Ifm5la47EVy
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html: /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
